#
# spec file for package python-python-louvain
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         skip_python2 1
%define         skip_python36 1
%{?sle15_python_module_pythons}
Name:           python-python-louvain
Version:        0.16
Release:        2.5
Summary:        Louvain algorithm for community detection
License:        BSD-3-Clause
URL:            https://github.com/taynaud/python-louvain
Source0:        https://files.pythonhosted.org/packages/source/p/python-louvain/python-louvain-%{version}.tar.gz
# PATCH-FIX-UPSTREAM fix-test-karate.patch gh#taynaud/python-louvain#95
Patch0:         fix-test-karate.patch
# PATCH-FIX-UPSTREAM tests-int-division.patch gh#taynaud/python-louvain#104
Patch1:         tests-int-division.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-networkx
Requires:       python-numpy
Requires(post): update-alternatives
Requires(postun): update-alternatives
Provides:       python-community = %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module networkx}
# /SECTION
%python_subpackages

%description
This module implements community detection.

It uses the louvain method described in Fast unfolding of
communities in large networks, Vincent D Blondel, Jean-Loup
Guillaume, Renaud Lambiotte, Renaud Lefebvre, Journal of
Statistical Mechanics: Theory and Experiment 2008(10), P10008 (12pp)

%prep
%autosetup -p1 -n python-louvain-%{version}

sed -i -e '/^#!\//, 1d' community/__init__.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/community
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pyunittest -v test_*.py

%post
%python_install_alternative community

%postun
%python_uninstall_alternative community

%files %{python_files}
%doc README.rst
%license LICENSE
%python_alternative %{_bindir}/community
%{python_sitelib}/community
%{python_sitelib}/python_louvain-%{version}*-info

%changelog
* Fri Mar 15 2024 Matej Cepl <mcepl@cepl.eu>
- Clean up the SPEC file
* Thu Mar 14 2024 Markéta Machová <mmachova@suse.com>
- Fix tests on Python 3.12 with tests-int-division.patch
* Fri Oct 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to 0.16:
  * Fix #86. When computing the change in modularity after alternating the
    block membership of a node, the resolution parameter was multiplied to the
    wrong term.
    As a result, the current code fails to correctly implement the Louvain
    algorithm, except for the special case when the resolution parameter is set
    to one.
- Add fix-test-karate.patch to fix tests with networkx<=2.7
  gh#taynaud/python-louvain#95
* Fri Apr 23 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 0.15:
  * Stop relabelling stable partitions, tests on power, doc fixes
- Do not build for Python 3.6, due to no NumPy.
* Tue Jul 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.14
  * Replace RandomState.permutation with RandomState.shuffle
  * include resolution parameter in __modularity calculation
  * docs fixes
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Jan  6 2020 Todd R <toddrme2178@gmail.com>
- Drop python2 subpackage due to dependencies dropping python2.
* Sat Dec 22 2018 Todd R <toddrme2178@gmail.com>
- Update to 0.13
  * Improve readme about library usage
  * Make cluster be 0,1...,n_clusters in the special case of no links
  * Include tests in sdists
  * Include license and documentation in sdists
* Thu Nov 15 2018 Todd R <toddrme2178@gmail.com>
- Initial version
